///
/// Functions that deal with all the possible sources.
/// @file       sources.h - pianod2
/// @author     Perette Barella
/// @date       2016-03-22
/// @copyright  Copyright (c) 2016-2020 Devious Fish. All rights reserved.
///

#pragma once

#include <config.h>

#include <string>
#include <vector>

#include <parsnip/parsnip_command.h>

#include "interpreter.h"

namespace UserData {
    class JSONData;
    class DataStore;
}
class User;

// Interfaces and names of specific sources
#define SOURCE_NAME_MANAGER "manager"

#ifdef WITH_PANDORA
#define SOURCE_NAME_PANDORA "pandora"
#endif

#ifdef WITH_TONEGENERATOR
#define SOURCE_NAME_TONEGENERATOR "tonegenerator"
#endif

#ifdef WITH_FILESYSTEM
#define SOURCE_NAME_FILESYSTEM "filesystem"
#endif

namespace UserData {
    class DataStore;
}

namespace Sources {
    const std::vector<std::string> &sourceNames ();
    bool isSource (const std::string &origin);
    void registerCommands (PianodParser *parser);
    void registerInterpreters (PianodDispatcher &dispatcher);
    void restore (UserData::DataStore *source_data, User *owner);
    void report (int verbose);
}

